; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
TWI_INI:
	; SCL(Hz) = CPU(Hz) / (16 + 2 * TWBR * 4^TWPS)	
	; Beispiel:										
	; 674 Hz = 22.000.000 / (16 + 2 * 255 * 4^3)	

	; TWI TWBR 				Bit RATE Register	
	ldi temp, (TWI_BIT_RATE);0..255				
	STS TWBR, temp
	; TWI TWSR 				STATUS-Register		
	ldi temp, (TWI_PRESCALER)
	andi temp,0b00000011	; 0...3 zulssig	
	STS TWSR, temp
	; TWI TWAR (nur SLAVE) 	Adress-Register		
	clr temp
	STS TWAR,temp
	; TWI TWCR 				Control-REGISTER	
	ldi temp, 1<<TWINT|1<<TWEA|0<<TWSTA|0<<TWSTO|0<<TWWC|1<<TWEN|0<<TWIE
	STS TWCR,temp
	; PULL-UP ein (ca. 30k)						
	sbi (TWI_SCL_PORT),(TWI_SCL_PIN_NR)
	sbi (TWI_SDA_PORT),(TWI_SDA_PIN_NR)
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
; TWI SCANNER																	
TWI_SCAN:
	clr temp1	; SLAVE Adresse	
TWI_SCAN_S:
	WDR
	push temp1
	; START			
	call TWI_MASTER_TRANSMITTER_START_TEMP1
	pop temp1
	tst TWI_FEHLER_CODE 		;TWI_FEHLER_CODE
	brne TWI_SCAN_w	
	push temp1
	; Anzeige		
	call ANZEIGE_3_STELLEN_TEMP1
	call ASCII_SPACE
	pop temp1
TWI_SCAN_w:
	inc temp1	; SLAVE Adresse	
	cpi temp1,127+1
	brne TWI_SCAN_S
	call TWI_STOP
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
; Anzeige, wenn SDA oder SCL gegen GND gezogen wird							   
TWI_BUS_FREE_CHECK:
	; kurze PAUSE, wichtig !
	call WAIT_1ms	
	; SCL			
	sbic (TWI_SCL_PIN),(TWI_SCL_PIN_NR)
	rjmp TWI_BUS_FREE_CHECK_SDA
	call GRAFIC_CLEAR
	call ASCII_CURSOR_ZEILE_1
	call ASCII_S
	call ASCII_C
	call ASCII_L
	call wait_1s
	rjmp TWI_BUS_FREE_CHECK
;------------------------------------------------------------------------------
TWI_BUS_FREE_CHECK_SDA:
	; SDA			
	sbic (TWI_SDA_PIN),(TWI_SDA_PIN_NR)
	ret
	call GRAFIC_CLEAR
	call ASCII_CURSOR_ZEILE_1
	call ASCII_S
	call ASCII_D
	call ASCII_A
	call wait_1s
	call ASCII_CURSOR_ZEILE_1
	rjmp TWI_BUS_FREE_CHECK
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
TWI_AUS:
	ldi temp, 1<<TWINT|0<<TWEA|0<<TWSTA|0<<TWSTO|0<<TWWC|0<<TWEN|0<<TWIE
	STS TWCR,temp
	call wait_100ms
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
;																			   
; MT-START-ROUTINE	(MASTER TRANSMITTER)									   
;																			   
; INPUT:	temp1 <= ADRESSE SLAVE											   
; OUTPUT: 	TWI_FEHLER_CODE (FEHLER_CODE)									   
;																			   
TWI_MASTER_TRANSMITTER_START_TEMP1:
	WDR
	clr  TWI_FEHLER_CODE 					; CLEAR							
	; START								
	ldi temp, (1<<TWINT)|(1<<TWSTA)|(1<<TWEN)
	STS TWCR, temp	
	rcall TWI_TWINT_WAIT					; warten, bis TWINT wieder = 1	
	tst  TWI_FEHLER_CODE 					; ERROR=0 ?						
	brne TWI_MASTER_TRANSMITTER_START_ERROR
	; Check TWSR						
	LDS temp,TWSR													
	andi temp, 0xF8
	cpi temp,  0x08							; 0x08 START erfolgreich		
	breq TWI_MASTER_TRANSMITTER_START_w
	cpi temp,  0x10							; 0x10 (repeated START)			
	breq TWI_MASTER_TRANSMITTER_START_w
	rjmp TWI_MASTER_TRANSMITTER_START_ERROR	; ERROR							
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_START_w:
	; Load SLA + "W"  (W=0) 			
	mov temp,temp1							; KOPIE							
	LSL  temp								; 1 x links						
	STS TWDR,temp
	; senden - Clear TWINT 				
	ldi temp, (1<<TWINT) | (1<<TWEN)							
	STS TWCR, temp
	; warten, bis TWINT wieder = 1		
	rcall TWI_TWINT_WAIT									
	tst  TWI_FEHLER_CODE 					; ERROR=0 ?						
	brne TWI_MASTER_TRANSMITTER_START_ERROR	; ERROR							
	; Check TWSR						
	LDS temp,TWSR												
	andi temp, 0xF8
	cpi temp,  0x18							; 0x18							
	brne TWI_MASTER_TRANSMITTER_START_ERROR	; ERROR							
	ret
;-------------------------------------------------------------------------------
; ERROR																			
TWI_MASTER_TRANSMITTER_START_ERROR:
	ldi temp,(ERROR_TWI_MT_START)
	mov TWI_FEHLER_CODE, temp  				;TWI_FEHLER_CODE				
	;STS(adr_WARNUNG_CODE),temp				; als WARNUNG speichern			
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
; 																			   
; Ein BYTE zum SLAVE zu senden										   	   	   
; 																			   
; INPUT:	temp1 <= DATEN													   
; OUT: 		TWI_FEHLER_CODE (FEHLER_CODE)   								   
; 																			   
TWI_MASTER_TRANSMITTER_DATA_TEMP1:
	WDR
	tst  TWI_FEHLER_CODE 							; ERROR=0 ?		
	breq TWI_MASTER_TRANSMITTER_DATA_TEMP1_RUN
	ret										
;-------------------------------------------------------------------------------
TWI_MASTER_TRANSMITTER_DATA_TEMP1_RUN:
	; 	Load DATA						
	STS TWDR, temp1							
	; senden - Clear TWINT 				
	ldi temp, (1<<TWINT) | (1<<TWEN)							
	STS TWCR, temp
	; warten, bis TWINT wieder = 1		
	rcall TWI_TWINT_WAIT
	tst  TWI_FEHLER_CODE 					 		; ERROR=0 ?		
	brne TWI_MASTER_TRANSMITTER_DATA_TEMP1_ERROR	; ERROR			
	; Check TWSR						
	LDS temp,TWSR
	andi temp,0xF8									; Bitmuster		
	cpi temp, 0x28									; 0x28			
	brne TWI_MASTER_TRANSMITTER_DATA_TEMP1_ERROR	; ERROR			
	ret
;-------------------------------------------------------------------------------
; ERROR																			
TWI_MASTER_TRANSMITTER_DATA_TEMP1_ERROR:
	ldi temp,(ERROR_TWI_MT_DATA)
	mov TWI_FEHLER_CODE, temp 						; TWI_FEHLER_CODE		
	STS(adr_WARNUNG_CODE),temp						; als WARNUNG speichern	
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
;																			   
; MR-START-ROUTINE													   		   
;																			   
; INPUT:	temp1 <= ADRESSE SLAVE											   
; OUT: 		TWI_FEHLER_CODE (FEHLER_CODE)   								   
;																			   
TWI_MASTER_RECEIVER_START_TEMP1:
	WDR
	clr TWI_FEHLER_CODE 							; CLEAR					
	; SRAM lschen						
	STS	(adr_TWI_BEREICH_READ+0),NULL
	STS	(adr_TWI_BEREICH_READ+1),NULL
	STS	(adr_TWI_BEREICH_READ+2),NULL
	STS	(adr_TWI_BEREICH_READ+3),NULL
	STS	(adr_TWI_BEREICH_READ+4),NULL
	STS	(adr_TWI_BEREICH_READ+5),NULL
	STS	(adr_TWI_BEREICH_READ+6),NULL
	; START 											
	ldi temp, (1<<TWINT | 1<<TWEA | 1<<TWSTA | 1<<TWEN )
	STS TWCR, temp	
	; warten, bis TWINT wieder = 1						
	rcall TWI_TWINT_WAIT									
	tst  TWI_FEHLER_CODE 							; ERROR=0 ?				
	brne TWI_MASTER_RECEIVER_START_TEMP1_ERROR
	; Check TWSR 										
	LDS temp,TWSR		
	andi temp, 0xF8									; Bitmuster				
	cpi temp,  0x08 								; 0x08 START erfolgreich
	breq TWI_MASTER_RECEIVER_START_TEMP1_RUN
	cpi temp,  0x10									; 0x10 (repeated START)	
	breq TWI_MASTER_RECEIVER_START_TEMP1_RUN
	rjmp TWI_MASTER_RECEIVER_START_TEMP1_ERROR
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_START_TEMP1_RUN:
	; Load SLA +"R" (R=1)								
	mov temp,temp1									; KOPIE			
	LSL temp										; 1 x links		
	ori temp, 0b00000001 							; BIT setzen	
	STS TWDR, temp
	; senden - Clear TWINT 								
	ldi temp, (1<<TWINT | 1<<TWEA  | 1<<TWEN )
	STS TWCR, temp
	; warten, bis TWINT wieder = 1						
	rcall TWI_TWINT_WAIT									
	tst  TWI_FEHLER_CODE 							; ERROR=0 ?				
	brne TWI_MASTER_RECEIVER_START_TEMP1_ERROR 
	; Check TWSR										
	LDS temp,TWSR
	andi temp, 0xF8									; Bitmuster		
	cpi temp,  0x40 								; SLA+R gesendet; ACK empfangen
	brne TWI_MASTER_RECEIVER_START_TEMP1_ERROR
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_START_TEMP1_ERROR:
	; ERROR						
	ldi temp,(ERROR_TWI_MR_START)
	mov TWI_FEHLER_CODE, temp 						;TWI_FEHLER_CODE			
	STS(adr_WARNUNG_CODE),temp						; als WARNUNG speichern		
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 08/2015															   
;																				
; Achtung, diese Routine verwenden, wenn 										
; mehrere! BYTE empfangen werden sollen											
;																				
; OUTPUT: temp1																	
; OUTPUT: TWI_FEHLER_CODE(FEHLER_CODE)	   										
;																				
TWI_MASTER_RECEIVER_DATA_TEMP1:
	WDR
	tst  TWI_FEHLER_CODE 						; ERROR=0 ?				
	breq TWI_MASTER_RECEIVER_DATA_TEMP1_RUN
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_TEMP1_RUN:
	; senden "ACK" (TWEA=1) fr mehrere Daten-Bytes 	
	ldi temp, (1<<TWINT | 1<<TWEA  | 1<<TWEN )
	STS TWCR, temp
	; TWINT abfragen									
	rcall TWI_TWINT_WAIT									
	tst  TWI_FEHLER_CODE 						; ERROR=0 ?				
	brne TWI_MASTER_RECEIVER_DATA_TEMP1_ERROR	; ERROR					
	; Check TWSR										
	LDS temp,TWSR
	andi temp,0xF8								; Bitmuster				
	cpi temp, 0x50								; Data Byte empfangen- ACK zurckgesendet
	brne TWI_MASTER_RECEIVER_DATA_TEMP1_ERROR
	; DATEN einlesen									
	LDS temp1, TWDR	
	ret
;-------------------------------------------------------------------------------
; ERROR																			
TWI_MASTER_RECEIVER_DATA_TEMP1_ERROR:
	ldi temp,(ERROR_TWI_MR_DATA)
	mov TWI_FEHLER_CODE, temp 					;TWI_FEHLER_CODE		
	STS(adr_WARNUNG_CODE),temp					; als WARNUNG speichern	
	clr temp1				
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
;																				
; Achtung, diese Routine verwenden, wenn 										
; nur ein! BYTE empfangen werden soll, oder wenn								
; das letzte! BYTE empfangen werden soll										
;																				
; OUTPUT: temp1																	
; OUTPUT: TWI_FEHLER_CODE(FEHLER_CODE)	   										
;																				
TWI_MASTER_RECEIVER_DATA_LAST_BYTE_TEMP1:
	tst  TWI_FEHLER_CODE 						; ERROR=0 ?				
	breq TWI_MASTER_RECEIVER_DATA_LAST_BYTE_TEMP1_w
	ret
;-------------------------------------------------------------------------------
TWI_MASTER_RECEIVER_DATA_LAST_BYTE_TEMP1_w:
	; senden "NOT ACK" (TWEA=0) fr letztes bzw fr ein Daten-Byte
	ldi temp, (1<<TWINT | 0<<TWEA  | 1<<TWEN )
	STS TWCR, temp
	; TWINT abfragen									
	rcall TWI_TWINT_WAIT		
	tst  TWI_FEHLER_CODE 						; ERROR=0 ?				
	brne TWI_MASTER_RECEIVER_DATA_LAST_BYTE_ERROR
	; Check TWSR										
	LDS temp,TWSR
	andi temp, 0xF8								; Bitmuster				
	cpi  temp, 0x58								; letztes Data Byte empfangen-NOT ACK zurckgesendet
	brne TWI_MASTER_RECEIVER_DATA_LAST_BYTE_ERROR
	; DATEN einlesen									
	LDS temp1, TWDR
	ret
;-------------------------------------------------------------------------------
; ERROR																			
TWI_MASTER_RECEIVER_DATA_LAST_BYTE_ERROR:
	ldi temp,(ERROR_TWI_MR_DATAEND)
	mov TWI_FEHLER_CODE, temp 					; TWI_FEHLER_CODE		
	STS(adr_WARNUNG_CODE),temp					; als WARNUNG speichern	
	clr temp1
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
; 																			   
; STOP- Routine																   
; 																			   
TWI_STOP:
	ldi temp, (1<<TWINT)|(1<<TWEN)|(1<<TWSTO)|0<<TWIE	; STOP								
	STS TWCR, temp	
	; kurze Pause
	call wait_1us
ret
; #############################################################################
; #############################################################################
; #############################################################################
; VERSION: 12/2015															   
; 																			   
; warten, bis das TWINT Flag gesetzt ist									   
; bei Zeitberschreitung Antwort mit ERROR									   
;																			   
; OUT: TWI_FEHLER_CODE														   
; 																			   
TWI_TWINT_WAIT:
	push temp1
	push temp2
	push temp3
	clr temp1
	clr temp2
	ldi temp3,10
TWI_TWINT_WAIT_s:
	WDR
	LDS temp, TWCR		; TWCR auslesen	
	sbrc temp, TWINT	; nchsten Befehl berspringen, wenn TWINT FLAG nicht gesetzt ist
	rjmp TWI_WAIT_FERTIG
	dec temp1
	brne TWI_TWINT_WAIT_s
	dec temp2
	brne TWI_TWINT_WAIT_s
	dec temp3
	brne TWI_TWINT_WAIT_s
	; ERROR					
	ldi temp,(ERROR_TWI_TWINT)
	mov TWI_FEHLER_CODE,temp
	STS(adr_WARNUNG_CODE),temp	; als WARNUNG speichern	
;-------------------------------------------------------------------------------
TWI_WAIT_FERTIG:
	pop temp3
	pop temp2
	pop temp1
	ret
; #############################################################################
; #############################################################################
; #############################################################################


