;																		
; TV-GRAFIC-SEIMOGRAPH 													
; 																		
; 360x256 PIXEL Vollrafik												
;																		
; ATmega1284P-22MHz														
;																		
; AVR-STUDIO 4															
; Bernhard.Erfurt@gmx.de												
; VERSION: 1 (11/2015)													
;																		

;																		
; Dieses Assembler-Programm generiert ein Fernsehbild.					
;																		
; Der Bildspeicher ergibt sich aus 360*256=92.160PIXEL=11.520 BYTE		
;																		

;																		
; Das TV-Bild generiert ein 64s TIMER (TIMER-0),						
; als Kontrolltimer fr die Taktkorrektur dient der TIMER-2.			
;																		
; Jede der 625 TV-Zeilen wird separat in der "TIM0_COMPA"generiert und 	
; die TV-Norm eingehalten.												
;																		

;																		
; Um wertvolle Takte in der Interruptroutine zu sparen, wird die Zeit 	
; der hinteren Schwarzschulter genutzt, um jede							
; TV-Bild-Daten_Zeile auf Daten zu prfen, liegen keine DATEN vor,		
; dann wird diese Zeile nicht geschrieben (Zeile bleibt Dunkel)			
; das spart Takte !!!													
;																		

;																		
;Nicht alle nutzbaren TV-Zeilen werden abgebildet, ca. 60 TV-ZEILEN		
;bleiben ungenutzt.														
;																		

;																		
; Die Datenausgabe (horizontale Pixel) generiert der PORT-A als 		
; Schieberegister, ist aber	dadurch komplett belegt, 					
; der PORT kann aber bei Bedarf abgendert werden.						
;																		


;																		
; GRN leuchtet: flackert, alles ok (Lebenslicht)						
; GELB leuchtet: ALARM wurde ausgelst									
; ROT  leuchtet: schwerer Fehler, aber Programm luft weiter			
;																		

;																		
; Blinken die LEDs, das ist nicht gut !									
; ROT blinkt: 				Fehler im Programmcheck						
; ROT+GELB blinken: 		WDR-Zeitberschreitung						
; ROT+GELB+GRN blinken: 	unkorrekter Interruptaufruf					
;																		


;												
; Anschlussbelegung PINS						
;												
; PA0 ==> OUT-DATA s/w (0,3V-1V)				
; PA1 ==> 										
; PA2 ==> 										
; PA3 ==> 										
; PA4 ==> 										
; PA5 ==> 										
; PA6 ==> 										
; PA7 ==> 										
;												
; PB0 ==> OUT SYNCHRONIMPULSE (0V-0,3V)			
; PB1 ==> 										
; PB2 ==> 										
; PB3 ==> OUT TESTAUSGANG (15625/2=7.812,5 Hz)	
; PB4 ==> 										
; PB5 ==> 										
; PB6 ==> 										
; PB7 ==> 										
;												
; PC0 ==> 										
; PC1 ==> 										
; PC2 ==> 										
; PC3 ==> 										
; PC4 ==>  										
; PC5 ==> LED GRN								
; PC6 ==> LED GELB								
; PC7 ==> LED ROT								
;												
; PD0 ==> 										
; PD1 ==> 										
; PD2 ==> 										
; PD3 ==> 										
; PD4 ==> 										
; PD5 ==>  										
; PD6 ==> 										
; PD7 ==> 										
;												

; ATmega1284P 									
.include "m1284pdef.inc"
; VERSION										
.equ VERSION								= 1
; KONSTANTEN									
.equ TAKT									= 22000000	; 22 MHz	
; ANZAHL DIAGRAMM-SPEICHERPLTZE				
.equ ANZ_DIAGRAMM_SPEICHERPLAETZE			= 60
; TIMER-0 (64s fr BILD)						
.equ TIMER0_CTC_FREQUENZ					= 15625/2
.equ TIMER0_N								= 8
.equ TIMER0_CTC								=(TAKT/(2*TIMER0_N*TIMER0_CTC_FREQUENZ))-1
.equ TIMER0_FREQUENZ_BERECHNET				=TAKT/(2*(TIMER0_N)*(1+TIMER0_CTC))
; TIMER-3-WERTE (20ms fr Uhr)					
.equ TIMER3_CTC_FREQUENZ					= 25
.equ TIMER3_N								= 64
.equ TIMER3_CTC								=(TAKT/(2*TIMER3_N*TIMER3_CTC_FREQUENZ))-1
.equ TIMER3_FREQUENZ_BERECHNET				=TAKT/(2*(TIMER3_N)*(1+TIMER3_CTC))
; TWI MASTER EINSTELLUNGEN						
.equ TWI_BIT_RATE							= 50		; 0..255  Bit-Rate					
.equ TWI_PRESCALER							= 1			; 0...3 (0=1 / 1=4 / 2=16 / 3=64)	
.equ TWI_SCL_BERECHNET						= TAKT/(16+(2*TWI_BIT_RATE)*(exp2(TWI_PRESCALER))*(exp2(TWI_PRESCALER)))
; TWI DS1307 (RTC)								
.equ DS1307_ADRESSE							= 104		; 104			
.equ DS1307_ERROR_WRITE						= 150		; ERROR-CODE	
.equ DS1307_ERROR_AUSLESEN					= 151		; ERROR-CODE	
; TWI BMA020									
.equ BMA020_ADRESSE							= 56		; 56			
.equ BMA020_ERROR_MESSUNG					= 66
; TWI 24FC1025 (EEPROM)							
.equ EEPROM_ADRESSE_A						= 80		; 80/84
; TV_BILD										
.equ TV_XSITZE								= 360
.equ TV_YSITZE								= 256
; TWI-SCL										
.equ TWI_SCL_PIN_NR							= 0
.equ TWI_SCL_PORT							= PORTC
.equ TWI_SCL_PIN							= PINC
; TWI-SDA										
.equ TWI_SDA_PIN_NR							= 1
.equ TWI_SDA_PORT							= PORTC
.equ TWI_SDA_PIN							= PINC
; TASTEN-WERTE									
.equ TASTE_MENUE_PLUS						= 1
.equ TASTE_MENUE_MINUS						= 2
.equ TASTE_PLUS								= 4
.equ TASTE_MINUS							= 8
; TASTE-A (MENUE +)								
.equ TASTE_A_PIN_NR							= 0		; WERT-1
.equ TASTE_A_DDR							= DDRD
.equ TASTE_A_PORT							= PORTD
.equ TASTE_A_PIN							= PIND
; TASTE-B (MENUE -)								
.equ TASTE_B_PIN_NR							= 3		; WERT-2
.equ TASTE_B_DDR							= DDRD
.equ TASTE_B_PORT							= PORTD
.equ TASTE_B_PIN							= PIND
; TASTE-C (WERT +)								
.equ TASTE_C_PIN_NR							= 2		; WERT-4
.equ TASTE_C_DDR							= DDRD
.equ TASTE_C_PORT							= PORTD
.equ TASTE_C_PIN							= PIND
; TASTE-D (WERT -)								
.equ TASTE_D_PIN_NR							= 1		; WERT-8
.equ TASTE_D_DDR							= DDRD
.equ TASTE_D_PORT							= PORTD
.equ TASTE_D_PIN							= PIND
; LED-GRUEN										
.equ LED_GRUEN_PIN_NR						= 5
.equ LED_GRUEN_DDR							= DDRC
.equ LED_GRUEN_PORT							= PORTC
; LED-GELB										
.equ LED_GELB_PIN_NR						= 6
.equ LED_GELB_DDR							= DDRC
.equ LED_GELB_PORT							= PORTC
; LED-ROT										
.equ LED_ROT_PIN_NR							= 7
.equ LED_ROT_DDR							= DDRC
.equ LED_ROT_PORT							= PORTC
; TV-DATA										
.equ TV_DATA_PIN_NR							= 0
.equ TV_DATA_DDR							= DDRA
.equ TV_DATA_PORT							= PORTA
; TV-SYNCHRON									
.equ TV_SYNC_PIN_NR							= 0
.equ TV_SYNC_DDR							= DDRB
.equ TV_SYNC_PORT							= PORTB
; FEHLER-CODES-TWI								
.equ ERROR_TWI_TWINT						= 100
.equ ERROR_TWI_MT_START						= 101
.equ ERROR_TWI_MT_DATA						= 102
.equ ERROR_TWI_MR_START						= 103
.equ ERROR_TWI_MR_SLA						= 104
.equ ERROR_TWI_MR_DATA						= 105
.equ ERROR_TWI_MR_DATAEND					= 106

; REGISTER												
.def TWI_FEHLER_CODE= R6
.def SREG_KOPIE		= R7	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def temp_KOPIE		= R8	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def temp1_KOPIE	= R9	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def ZL_KOPIE		= R10	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def ZH_KOPIE		= R11	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def TV_ZEILE_NR_L 	= R12	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def TV_ZEILE_NR_H 	= R13	; BILDERZEIGUNG - nutzt nur der 64s-TIMER-Interrupt !
.def NULL 			= R14	; ist immer NULL 	
.def EINS 			= R15	; ist immer EINS 	
.def temp 			= R16
.def temp1 			= R17
.def temp2 			= R18
.def temp3 			= R19
.def temp4 			= R20
.def temp5 			= R21
.def temp6 			= R22
.def temp7 			= R23
.def temp8 			= R24
.def temp9 			= R25

; SRAM-BELEGUNG Adr:0x0100-0x40FF(256-16.639=16383)		
.equ adr_DATEN				 			=SRAM_START+0	
.equ adr_ERROR_CODE						=SRAM_START+2	
.equ adr_ERROR_WERT						=SRAM_START+3	
.equ adr_WARNUNG_CODE					=SRAM_START+4	
.equ adr_WARNUNG_WERT1					=SRAM_START+5
.equ adr_WARNUNG_WERT2					=SRAM_START+6
.equ adr_WARNUNG_WERT3					=SRAM_START+7
.equ adr_WARNUNG_WERT4					=SRAM_START+8

.equ adr_MENUE							=SRAM_START+10	
.equ adr_TASTE							=SRAM_START+11	
.equ adr_DIAGRAMM_NR					=SRAM_START+12	

.equ adr_FREIGABE_BMA020_AUTO_OFFSET	=SRAM_START+14	; vom TIMER					
.equ adr_FREIGABE_DIAGRAMM_MARKIERUNG	=SRAM_START+15
.equ adr_FREIGABE_DIAGRAMM_ZEIT			=SRAM_START+16	; vom TIMER					

.equ adr_ss20							=SRAM_START+20	; 20ms Sekunden				
.equ adr_ss								=SRAM_START+21	; Sekunden					
.equ adr_mm								=SRAM_START+22	; Minuten					
.equ adr_hh								=SRAM_START+23	; Stunden					
.equ adr_TAG							=SRAM_START+24	; TAG						
.equ adr_MONAT							=SRAM_START+25	; Monat						
.equ adr_JAHR							=SRAM_START+26	; JAHR						
.equ adr_WOCHENTAG						=SRAM_START+27	; 1=Mo 7=So					

.equ adr_PROGRAMMSTART_ss				=SRAM_START+30
.equ adr_PROGRAMMSTART_mm				=SRAM_START+31
.equ adr_PROGRAMMSTART_hh				=SRAM_START+32
.equ adr_PROGRAMMSTART_TAG				=SRAM_START+33
.equ adr_PROGRAMMSTART_MONAT			=SRAM_START+34
.equ adr_PROGRAMMSTART_JAHR				=SRAM_START+35


.equ adr_BMA020_ALARM_SCHWELLE			=SRAM_START+60	; Schwellwert				
.equ adr_BMA020_ALARM_TIMER				=SRAM_START+61	; ZHLER					
.equ adr_BMA020_X_L						=SRAM_START+62	; Ergebnis-X-16Bit			
.equ adr_BMA020_X_H						=SRAM_START+63
.equ adr_BMA020_Y_L						=SRAM_START+64	; Ergebnis-Y-16Bit			
.equ adr_BMA020_Y_H						=SRAM_START+65
.equ adr_BMA020_Z_L						=SRAM_START+66	; Ergebnis-Z-16Bit			
.equ adr_BMA020_Z_H						=SRAM_START+67
.equ adr_BMA020_X						=SRAM_START+68	; Ergebnis-X-8Bit			
.equ adr_BMA020_Y						=SRAM_START+69	; Ergebnis-Y-8Bit			
.equ adr_BMA020_Z						=SRAM_START+70	; Ergebnis-Z-8Bit			
.equ adr_BMA020_X_OFFSET_L				=SRAM_START+71	; OFFSET					
.equ adr_BMA020_X_OFFSET_H				=SRAM_START+72
.equ adr_BMA020_Y_OFFSET_L				=SRAM_START+73	; OFFSET					
.equ adr_BMA020_Y_OFFSET_H				=SRAM_START+74
.equ adr_BMA020_Z_OFFSET_L				=SRAM_START+75	; OFFSET					
.equ adr_BMA020_Z_OFFSET_H				=SRAM_START+76

.equ adr_TWI_BEREICH_READ				=SRAM_START+100	; BEREICH fr Master TWI/I2C	

.equ adr_GRAFIC_CURSOR_L				=SRAM_START+200	; CURSOR TV-ZEILE vom CURSOR
.equ adr_GRAFIC_CURSOR_H				=SRAM_START+201	
.equ adr_GRAFIC_CURSOR_SPALTE			=SRAM_START+202	; CURSOR-SPALTE (0..19)		
.equ adr_GRAFIC_FARBE					=SRAM_START+203	; 0=wei 1=schwarz			
.equ adr_GRAFIC_PUNKT_GROESSE			=SRAM_START+204	; PUNKT-GRSSE 0...9		

.equ adr_ZEITSTEMPEL_ss					=SRAM_START+300
.equ adr_ZEITSTEMPEL_mm					=SRAM_START+301
.equ adr_ZEITSTEMPEL_hh					=SRAM_START+302
.equ adr_ZEITSTEMPEL_TAG				=SRAM_START+303
.equ adr_ZEITSTEMPEL_MONAT				=SRAM_START+304
.equ adr_ZEITSTEMPEL_JAHR				=SRAM_START+305
.equ adr_ZEITSTEMPEL_WOCHENTAG			=SRAM_START+306

.equ adr_DATA_X_360						=SRAM_START+400
.equ adr_DATA_Y_360						=SRAM_START+800
.equ adr_DATA_Z_360						=SRAM_START+1200

.equ adr_TV_ZEIGER_DATA_L				=SRAM_START+2000	; ZEIGER fr BILD-DATEN		
.equ adr_TV_ZEIGER_DATA_H				=SRAM_START+2001

.equ adr_TV_BILDBEREICH					=SRAM_START+3000 	;(256*360=10520 Bytes)		
.equ adr_TV_BILDBEREICH_ENDE			=SRAM_START+3000+(45*256)-1

.equ adr_SRAM_CHECK						=SRAM_START+16000	; SRAM CHECK muss immer "S" sein	

; EEPRPM-BELEGUNG										
.equ eep_EEPROM_WERKSEINSTELLUNG		=10
.equ eep_EEPROM_DIAGRAMM_DATA			=100

.cseg						;Beginn eines Code-Segmentes
.org 0						;Startadresse=0				
.org 0x0000 rjmp RESET 			 ; Reset									
.org 0x0002 rjmp INTERRUPT_ERROR ;rjmp INT0 ; IRQ0							
.org 0x0004 rjmp INTERRUPT_ERROR ;rjmp INT1 ; IRQ1							
.org 0x0006 rjmp INTERRUPT_ERROR ;rjmp INT2 ; IRQ2							
.org 0x0008 rjmp INTERRUPT_ERROR ;rjmp PCINT0 ; PCINT0						
.org 0x000A rjmp INTERRUPT_ERROR ;rjmp PCINT1 ; PCINT1						
.org 0x000C rjmp INTERRUPT_ERROR ;rjmp PCINT2 ; PCINT2						
.org 0x000E rjmp INTERRUPT_ERROR ;rjmp PCINT3 ; PCINT3						
.org 0x0010 jmp WDT 		; Watchdog Timeout								
.org 0x0012 rjmp INTERRUPT_ERROR ;rjmp TIM2_COMPA ; Timer2 CompareA			
.org 0x0014 rjmp INTERRUPT_ERROR ;rjmp TIM2_COMPB ; Timer2 CompareB			
.org 0x0016 rjmp INTERRUPT_ERROR ;rjmp TIM2_OVF 	; Timer2 Overflow		
.org 0x0018 rjmp INTERRUPT_ERROR ;rjmp TIM1_CAPT ; Timer1 Capture			
.org 0x001A rjmp INTERRUPT_ERROR ;rjmp TIM1_COMPA ; Timer1 CompareA			
.org 0x001C rjmp INTERRUPT_ERROR ;rjmp TIM1_COMPB ; Timer1 CompareB			
.org 0x001E rjmp INTERRUPT_ERROR ;TIM1_OVF 	; Timer1 Overflow				
.org 0x0020 rjmp TIM0_COMPA ; Timer0 CompareA								
.org 0x0022 rjmp INTERRUPT_ERROR ;rjmp TIM0_COMPB ; Timer0 CompareB			
.org 0x0024 rjmp INTERRUPT_ERROR ;rjmp TIM0_OVF 	; Timer0 Overflow		
.org 0x0026 rjmp INTERRUPT_ERROR ;rjmp SPI_STC ; SPI Transfer Complete		
.org 0x0028 rjmp INTERRUPT_ERROR ;rjmp USART0_RXC ; USART0 RX Complete		
.org 0x002A rjmp INTERRUPT_ERROR ;rjmp USART0_UDRE ; USART0,UDR Empty		
.org 0x002C rjmp INTERRUPT_ERROR ;rjmp USART0_TXC ; USART0 TX Complete		
.org 0x002E rjmp INTERRUPT_ERROR ;rjmp ANA_COMP ; Analog Comparator			
.org 0x0030 rjmp INTERRUPT_ERROR ;rjmp ADC ; ADC Conversion Complete		
.org 0x0032 rjmp INTERRUPT_ERROR ;rjmp EE_RDY ; EEPROM Ready				
.org 0x0034 rjmp INTERRUPT_ERROR ;rjmp TWI ; 2-wire Serial					
.org 0x0036 rjmp INTERRUPT_ERROR ;rjmp SPM_RDY ; SPM Ready					
.org 0x0038 rjmp INTERRUPT_ERROR ;rjmp USART1_RXC ; USART1 RX Complete		
.org 0x003A rjmp INTERRUPT_ERROR ;rjmp USART1_UDRE ; USART1,UDR Empty		
.org 0x003C rjmp INTERRUPT_ERROR ;rjmp USART1_TXC ; USART1 TX Complete		
.org 0x003E rjmp INTERRUPT_ERROR ;rjmp TIM3_CAPT ; Timer3 Capture			
.org 0x0040 rjmp TIM3_COMPA  ; Timer3 CompareA								
.org 0x0042 rjmp INTERRUPT_ERROR ;rjmp TIM3_COMPB ; Timer3 CompareB			
.org 0x0044 rjmp INTERRUPT_ERROR ;rjmp TIM3_OVF 	; Timer3 Overflow		
; Unkorrekten Interrupt Aufruf 						
INTERRUPT_ERROR:
	CLI											; INTERRUPTS sperren	
	cbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN an   
	cbi (LED_GELB_PORT),(LED_GELB_PIN_NR)		; GELB an	
	cbi (LED_ROT_PORT),(LED_ROT_PIN_NR)			; ROT  an	
	call wait_100ms
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	sbi (LED_GELB_PORT),(LED_GELB_PIN_NR)		; GELB aus  
	sbi (LED_ROT_PORT),(LED_ROT_PIN_NR)			; ROT  aus	
	call wait_100ms
	rjmp INTERRUPT_ERROR
;-------------------------------------------------------------------------------
RESET:                        
; STACK initialisieren								
	ldi temp, LOW(RAMEND)
    out SPL, temp
    ldi temp, HIGH(RAMEND)
    out SPH, temp
; SRAM_CLEAR										
	call SRAM_CLEAR
; REGISTER_CLEAR									
	call REGISTER_CLEAR
; PORT_CLEAR										
	call PORT_CLEAR
; STARTWERTE										
	; NULL						
	clr NULL
	; EINS						
	ldi temp,1
	mov EINS,temp
	; SRAM CHECK				
	ldi temp,'S'
	STS(adr_SRAM_CHECK),temp
	; BILD						
	ldi temp,0b00000001
	STS(adr_TV_BILDBEREICH),temp
	STS(adr_TV_BILDBEREICH_ENDE-44),temp
	ldi temp,0b10000000
	STS(adr_TV_BILDBEREICH+44),temp
	STS(adr_TV_BILDBEREICH_ENDE),temp
	; TV_ZEILE					
	ldi temp1,LOW (-1)
	ldi temp2,HIGH(-1)
	mov TV_ZEILE_NR_L,temp1
	mov TV_ZEILE_NR_H,temp2
	; DATUM				
	ldi temp,1
	STS(adr_TAG),temp
	ldi temp,1
	STS(adr_MONAT),temp
	ldi temp,16
	STS(adr_JAHR),temp
	ldi temp,1
	STS(adr_WOCHENTAG),temp
	; ZEIT				
	ldi temp,0
	STS(adr_hh),temp	; hh	
	ldi temp,0
	STS(adr_mm),temp	; mm	
	ldi temp,0
	STS(adr_ss),temp	; ss	
	; BMA020_ALARM_SCHWELLE
	ldi temp,6
	STS(adr_BMA020_ALARM_SCHWELLE),temp
	; BMA020_ALARM_TIMER	
	ldi temp,255
	STS(adr_BMA020_ALARM_TIMER),temp
; LED_INITIALISIERUNG										
	call LED_INITIALISIERUNG
; TV_PIN_INITIALISIERUNG									
	call TV_PIN_INITIALISIERUNG
; WDR_INITIALISIERUNG										
	call WDR_INITIALISIERUNG
; TWI_INI													
	call TWI_INI
; BMA020_INITIALISIERUNG									
	call BMA020_INITIALISIERUNG
; BMA020_OFFSET_SCHNELL										
	call BMA020_OFFSET_SCHNELL
; TASTEN_INITIALISIERUNG									
	call TASTEN_INITIALISIERUNG
; TIMER INITALISIERUNG										
	call TIMER0_INITIALISIERUNG_CTC
	call TIMER2_INITIALISIERUNG
	call TIMER3_INITIALISIERUNG_CTC
; Interrupts freigeben										
	sei
; ##############################################################################
; ##############################################################################
; ##############################################################################
	call WAIT_1s								; EINSCHWINGEN	
	call PROGRAMM_CHECK
	sbi (LED_GRUEN_PORT),LED_GRUEN_PIN_NR		; GRN aus		
	sbi (LED_GELB_PORT),LED_GELB_PIN_NR			; GELB aus		
	sbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  aus		

	call TASTEN_CHECK
	call DS1307_CHECK
	call BMA020_CHECK
	call TWI_EEPROM_CHECK
	call TWI_BUS_FREE_CHECK

	call GRAFIC_CLEAR
	call ANZEIGE_BEGRUESSUNG
	call EEPROM_KONFIGURATION_LADEN
	call DS1307_UHR_AUSLESEN
	call PROGRAMMSTART_ZEIT_SAVE
	call WAIT_1s


	call DIAGRAMM_INITIALISIERUNG
; ##############################################################################
; ##############################################################################
; ##############################################################################
LOOP:
	WDR										; Watch-Dog-RESET	
	call BMA020_MESSUNG
	call BMA020_OFFSET_AUTOMATIK
	call TASTEN_ABFRAGE
	call MENUE
	call ANZEIGE_ERROR
	call TASTEN_WAIT
	call PROGRAMM_CHECK
rjmp LOOP
; ##############################################################################
; ##############################################################################
; ##############################################################################
.include "TV_TIMER.asm"				; TIMER							
.include "TV_BILD_MACRO.asm"		; MAKROS						
.include "TV_BILD.asm"				; BILDAUFBAU					
.include "TV_WAIT_22MHZ.asm"		; 22 MHz						
.include "TV_SONSTIGES.asm"
.include "TV_EEPROM.asm"
.include "TV_TASTEN.asm"
.include "TV_MENUE.asm"
.include "TV_ANZEIGE.asm"
.include "TV_ANZEIGE_KURZ.asm"
.include "TV_ANZEIGE_ZAHLEN.asm"
.include "TV_GRAFIC_ALLGEMEIN.asm"
.include "TV_GRAFIC_DIAGRAMM.asm"
.include "TV_GRAFIC_PUNKT.asm"
.include "TV_TWI.asm"
.include "TV_TWI_DS1307.asm"
.include "TV_TWI_BMA020.asm"
.include "TV_TWI_24FC1025.asm"
.include "TV_ASCII.asm"
.include "TV_ASCII_ALPHABET.asm"
.include "TV_TABELLE_ASCII.asm"



;-------------------------------------------------------------------------------
TEXT_BEGRUESSUNG_1:
.db "TV SEISMOGRAPH    2015",0,0
TEXT_BEGRUESSUNG_2:
.db " ",0
TEXT_BEGRUESSUNG_3:
.db "ATmega1284p 22MHz",0
TEXT_BEGRUESSUNG_4:
.db " ",0
TEXT_BEGRUESSUNG_5:
.db "360x256Pixel ",0
TEXT_BEGRUESSUNG_6:
.db " ",0
TEXT_BEGRUESSUNG_7:
.db "ASCII 22x10 (16x24)",0
TEXT_BEGRUESSUNG_8:
.db " ",0
TEXT_BEGRUESSUNG_9:
.db " ",0
TEXT_BEGRUESSUNG_10:
.db "V1 11/2015 ",0
;-------------------------------------------------------------------------------

